@@ -77,15 +77,17 @@ def statistical_analysis(data: pd.DataFrame,
                          dtypes: Dict[str, str],
                          identifiers: Dict[str, object],
                          problem_definition: ProblemDefinition,
+                         exceptions: list = ['__mdb_original_index'],
                          seed_nr: int = 420) -> StatisticalAnalysis:
     seed(seed_nr)
     log.info('Starting statistical analysis')
     df = cleaner(data, dtypes, problem_definition.pct_invalid,
                  identifiers, problem_definition.target, 'train', problem_definition.timeseries_settings,
                  problem_definition.anomaly_detection)
+    columns = [col for col in df.columns if col not in exceptions]
 
-    missing = {col: len([x for x in df[col] if x is None]) / len(df[col]) for col in df.columns}
-    distinct = {col: len(set([str(x) for x in df[col]])) / len(df[col]) for col in df.columns}
+    missing = {col: len([x for x in df[col] if x is None]) / len(df[col]) for col in columns}
+    distinct = {col: len(set([str(x) for x in df[col]])) / len(df[col]) for col in columns}
 
     nr_rows = len(df)
     target = problem_definition.target
@@ -112,7 +114,7 @@ def statistical_analysis(data: pd.DataFrame,
     histograms = {}
     buckets = {}
     # Get histograms for each column
-    for col in df.columns:
+    for col in columns:
         histograms[col] = None
         buckets[col] = None
         if dtypes[col] in (dtype.categorical, dtype.binary, dtype.tags):
@@ -146,7 +148,7 @@ def statistical_analysis(data: pd.DataFrame,
         train_observed_classes = None
 
     bias = {}
-    for col in df.columns:
+    for col in columns:
         S, biased_buckets = compute_entropy_biased_buckets(histograms[col])
         bias[col] = {
             'entropy': S,
@@ -155,7 +157,7 @@ def statistical_analysis(data: pd.DataFrame,
         }
 
     avg_words_per_sentence = {}
-    for col in df.columns:
+    for col in columns:
         if dtypes[col] in (dtype.rich_text, dtype.short_text):
             words_per_sentence = []
             for item in df[col]:
