@@ -4,7 +4,7 @@ from lightwood.api.types import TimeseriesSettings
 
 
 def get_inferred_timestamps(df: pd.DataFrame, col: str, deltas: dict, tss: TimeseriesSettings) -> pd.DataFrame:
-    nr_predictions = tss.nr_predictions
+    horizon = tss.horizon
     if tss.group_by:
         gby = [f'group_{g}' for g in tss.group_by]
 
@@ -18,10 +18,10 @@ def get_inferred_timestamps(df: pd.DataFrame, col: str, deltas: dict, tss: Times
                 series_delta = deltas['__default'][col]
         else:
             series_delta = deltas['__default'][col]
-        timestamps = [last + t * series_delta for t in range(nr_predictions)]
+        timestamps = [last + t * series_delta for t in range(horizon)]
 
-        if tss.nr_predictions == 1:
-            timestamps = timestamps[0]  # preserves original input format if nr_predictions == 1
+        if tss.horizon == 1:
+            timestamps = timestamps[0]  # preserves original input format if horizon == 1
 
         df[f'order_{col}'].iloc[idx] = timestamps
     return df[f'order_{col}']
@@ -39,8 +39,8 @@ def add_tn_conf_bounds(data: pd.DataFrame, tss_args: TimeseriesSettings):
     for idx, row in data.iterrows():
         error_increase = [row['confidence']] + \
                          [row['confidence'] * np.log(np.e + t / 2)  # offset by e so that y intercept is 1
-                          for t in range(1, tss_args.nr_predictions)]
-        data['confidence'].iloc[idx] = [row['confidence'] for _ in range(tss_args.nr_predictions)]
+                          for t in range(1, tss_args.horizon)]
+        data['confidence'].iloc[idx] = [row['confidence'] for _ in range(tss_args.horizon)]
 
         preds = row['prediction']
         width = row['upper'] - row['lower']
