@@ -3,7 +3,6 @@ import numpy as np
 import pandas as pd
 from typing import List
 from lightwood.api.types import ProblemDefinition
-from lightwood.api.high_level import predictor_from_problem
 from tests.utils.timing import train_and_check_time_aim
 from sktime.forecasting.base import ForecastingHorizon
 from sktime.forecasting.arima import AutoARIMA
@@ -14,18 +13,18 @@ np.random.seed(0)
 
 
 class TestTimeseries(unittest.TestCase):
-    def check_ts_prediction_df(self, df: pd.DataFrame, nr_preds: int, orders: List[str]):
+    def check_ts_prediction_df(self, df: pd.DataFrame, horizon: int, orders: List[str]):
         for idx, row in df.iterrows():
-            lower = [row['lower']] if nr_preds == 1 else row['lower']
-            upper = [row['upper']] if nr_preds == 1 else row['upper']
-            prediction = [row['prediction']] if nr_preds == 1 else row['prediction']
+            lower = [row['lower']] if horizon == 1 else row['lower']
+            upper = [row['upper']] if horizon == 1 else row['upper']
+            prediction = [row['prediction']] if horizon == 1 else row['prediction']
 
-            assert len(prediction) == nr_preds
+            assert len(prediction) == horizon
 
             for oby in orders:
-                assert len(row[f'order_{oby}']) == nr_preds
+                assert len(row[f'order_{oby}']) == horizon
 
-            for t in range(nr_preds):
+            for t in range(horizon):
                 assert lower[t] <= prediction[t] <= upper[t]
 
     def split_arrivals(self, data: pd.DataFrame, grouped: bool) -> (pd.DataFrame, pd.DataFrame):
@@ -52,7 +51,7 @@ class TestTimeseries(unittest.TestCase):
         train, test = self.split_arrivals(data, grouped=True)
         target = 'Traffic'
         order_by = 'T'
-        nr_preds = 2
+        horizon = 2
         window = 5
         jai = json_ai_from_problem(train,
                                    ProblemDefinition.from_dict({'target': target,
@@ -62,7 +61,7 @@ class TestTimeseries(unittest.TestCase):
                                                                     'use_previous_target': True,
                                                                     'allow_incomplete_history': True,
                                                                     'group_by': ['Country'],
-                                                                    'nr_predictions': nr_preds,
+                                                                    'horizon': horizon,
                                                                     'order_by': [order_by],
                                                                     'period_intervals': (('daily', 7),),
                                                                     'window': window
@@ -75,7 +74,7 @@ class TestTimeseries(unittest.TestCase):
             "module": "SkTime",
             "args": {
                 "stop_after": "$problem_definition.seconds_per_mixer",
-                "n_ts_predictions": "$problem_definition.timeseries_settings.nr_predictions",
+                "n_ts_predictions": "$problem_definition.timeseries_settings.horizon",
                 "model_path": "'trend.TrendForecaster'",  # use a cheap forecaster
                 "hyperparam_search": False,  # disable this as it's expensive and covered in test #3
             },
@@ -87,16 +86,16 @@ class TestTimeseries(unittest.TestCase):
         # Test with a short time aim
         train_and_check_time_aim(pred, train)
         preds = pred.predict(test)
-        self.check_ts_prediction_df(preds, nr_preds, [order_by])
+        self.check_ts_prediction_df(preds, horizon, [order_by])
 
         # test allowed incomplete history
         preds = pred.predict(test[:window - 1])
-        self.check_ts_prediction_df(preds, nr_preds, [order_by])
+        self.check_ts_prediction_df(preds, horizon, [order_by])
 
         # test inferring mode
         test['__mdb_make_predictions'] = False
         preds = pred.predict(test)
-        self.check_ts_prediction_df(preds, nr_preds, [order_by])
+        self.check_ts_prediction_df(preds, horizon, [order_by])
 
         # Additionally, check timestamps are further into the future than test dates
         latest_timestamp = pd.to_datetime(test[order_by]).max().timestamp()
@@ -116,7 +115,7 @@ class TestTimeseries(unittest.TestCase):
         train_df, test_df = self.split_arrivals(data, grouped=False)
         target = 'Traffic'
         order_by = 'T'
-        nr_preds = 2
+        horizon = 2
         window = 5
         pred = predictor_from_problem(data,
                                       ProblemDefinition.from_dict({'target': target,
@@ -124,14 +123,14 @@ class TestTimeseries(unittest.TestCase):
                                                                    'timeseries_settings': {
                                                                        'use_previous_target': False,
                                                                        'allow_incomplete_history': False,
-                                                                       'nr_predictions': nr_preds,
+                                                                       'horizon': horizon,
                                                                        'order_by': [order_by],
                                                                        'window': window}
                                                                    }))
         pred.learn(train_df)
         preds = pred.predict(data.sample(frac=1)[0:10])
         self.assertTrue('original_index' in preds.columns)
-        self.check_ts_prediction_df(preds, nr_preds, [order_by])
+        self.check_ts_prediction_df(preds, horizon, [order_by])
 
         # test incomplete history, should not be possible
         self.assertRaises(Exception, pred.predict, test_df[:window - 1])
@@ -140,7 +139,7 @@ class TestTimeseries(unittest.TestCase):
         test_df['__mdb_make_predictions'] = False
         test_df = test_df.sample(frac=1)  # shuffle to test internal ordering logic
         preds = pred.predict(test_df)
-        self.check_ts_prediction_df(preds, nr_preds, [order_by])
+        self.check_ts_prediction_df(preds, horizon, [order_by])
 
         # Additionally, check timestamps are further into the future than test dates
         latest_timestamp = pd.to_datetime(test_df[order_by]).max().timestamp()
@@ -149,8 +148,6 @@ class TestTimeseries(unittest.TestCase):
                 assert timestamp > latest_timestamp
 
     def test_2_time_series_classification(self):
-        from lightwood.api.high_level import predictor_from_problem
-
         df = pd.read_csv('tests/data/arrivals.csv')
         target = 'Traffic'
         df[target] = df[target] > 100000
@@ -195,7 +192,7 @@ class TestTimeseries(unittest.TestCase):
         # synth square wave
         tsteps = 100
         target = 'Value'
-        n_preds = 20
+        horizon = 20
         t = np.linspace(0, 1, tsteps, endpoint=False)
         ts = [i + f for i, f in enumerate(signal.sawtooth(2 * np.pi * 5 * t, width=0.5))]
         df = pd.DataFrame(columns=['Time', target])
@@ -211,7 +208,7 @@ class TestTimeseries(unittest.TestCase):
                                             'timeseries_settings': {
                                                 'order_by': ['Time'],
                                                 'window': 5,
-                                                'nr_predictions': n_preds,
+                                                'horizon': horizon,
                                                 'historical_columns': [f'{target}_2x']
                                             }})
 
@@ -220,7 +217,7 @@ class TestTimeseries(unittest.TestCase):
             "module": "SkTime",
             "args": {
                 "stop_after": "$problem_definition.seconds_per_mixer",
-                "n_ts_predictions": "$problem_definition.timeseries_settings.nr_predictions",
+                "n_ts_predictions": "$problem_definition.timeseries_settings.horizon",
             }}]
 
         code = code_from_json_ai(json_ai)
@@ -243,6 +240,6 @@ class TestTimeseries(unittest.TestCase):
             forecaster = AutoARIMA()
             fh = ForecastingHorizon([i for i in range(int(tsteps * 0.8))], is_relative=True)
             forecaster.fit(train[target], fh=fh)
-            manual_preds = forecaster.predict(fh[1:n_preds + 1]).tolist()
+            manual_preds = forecaster.predict(fh[1:horizon + 1]).tolist()
             lw_preds = [p[0] for p in ps['prediction']]
             assert np.allclose(manual_preds, lw_preds, atol=1)
